pub enum ConstellationInterest {
StorageEvent,
}Expand description
Identifies a category of events/notifications that a pipeline can register interest in with the constellation. When a pipeline has active listeners for events in a given category, it registers interest so the constellation only sends notifications to pipelines that care.
Variants
StorageEvent
Interest in storage events (fired when another same-origin pipeline modifies storage).