pub enum HistoryTraversalSource {
Embedder,
Script,
}Expand description
The source of a [HistoryTraversalRequest].
Variants
Embedder
The traversal was triggered from the embedder, which means it is expecting a notification when the request has completed.
Script
The traversal was triggered from the script event loop.