pub enum JobResult {
RejectPromise(JobError),
ResolvePromise(JobResultValue),
}Expand description
Messages sent from Job algorithms steps running in the SW manager, in order to resolve or reject the job promise.
Variants
RejectPromise(JobError)
ResolvePromise(JobResultValue)