pub enum PaintMetricEvent {
FirstPaint(PaintTimingInfo, bool),
FirstContentfulPaint(PaintTimingInfo, bool),
LargestContentfulPaint(PaintTimingInfo, LCPCandidateID),
}Expand description
A description of a paint metric that is sent from the Servo renderer to the constellation and then forwarded to the script thread.
Variants
FirstPaint(PaintTimingInfo, bool)
FirstContentfulPaint(PaintTimingInfo, bool)
LargestContentfulPaint(PaintTimingInfo, LCPCandidateID)