pub struct LoadData {Show 19 fields
pub load_origin: LoadOrigin,
pub url: ServoUrl,
pub about_base_url: Option<ServoUrl>,
pub creator_pipeline_id: Option<PipelineId>,
pub method: Method,
pub headers: HeaderMap,
pub data: Option<RequestBody>,
pub js_eval_result: Option<String>,
pub referrer: Referrer,
pub referrer_policy: ReferrerPolicy,
pub policy_container: Option<PolicyContainer>,
pub srcdoc: String,
pub inherited_secure_context: Option<bool>,
pub inherited_insecure_requests_policy: Option<InsecureRequestsPolicy>,
pub has_trustworthy_ancestor_origin: bool,
pub crash: Option<String>,
pub destination: Destination,
pub creation_sandboxing_flag_set: SandboxingFlagSet,
pub container_document_encoding: Option<&'static Encoding>,
}Expand description
can be passed to LoadUrl to load a page with GET/POST
parameters or headers
Fields
load_origin: LoadOriginThe origin where the load started.
url: ServoUrlThe URL.
about_base_url: Option<ServoUrl>creator_pipeline_id: Option<PipelineId>The creator pipeline id if this is an about:blank load.
method: MethodThe method.
headers: HeaderMapThe headers.
data: Option<RequestBody>The data that will be used as the body of the request.
js_eval_result: Option<String>The result of evaluating a javascript scheme url.
referrer: ReferrerThe referrer.
referrer_policy: ReferrerPolicyThe referrer policy.
policy_container: Option<PolicyContainer>The policy container.
srcdoc: StringThe source to use instead of a network response for a srcdoc document.
inherited_secure_context: Option<bool>The inherited context is Secure, None if not inherited
inherited_insecure_requests_policy: Option<InsecureRequestsPolicy>The inherited policy for upgrading insecure requests; None if not inherited.
has_trustworthy_ancestor_origin: boolWhether the page’s ancestors have potentially trustworthy origin
crash: Option<String>Servo internal: if crash details are present, trigger a crash error page with these details.
destination: DestinationDestination, used for CSP checks
creation_sandboxing_flag_set: SandboxingFlagSetThe “creation sandboxing flag set” that this Pipeline should use when it is created. See https://html.spec.whatwg.org/multipage/#determining-the-creation-sandboxing-flags.
container_document_encoding: Option<&'static Encoding>If this is a load operation for an <iframe> whose origin is same-origin with its
container documents origin then this is the encoding of the container document.
Implementations
Sourceimpl LoadData
impl LoadData
Sourcepub fn new(
load_origin: LoadOrigin,
url: ServoUrl,
about_base_url: Option<ServoUrl>,
creator_pipeline_id: Option<PipelineId>,
referrer: Referrer,
referrer_policy: ReferrerPolicy,
inherited_secure_context: Option<bool>,
inherited_insecure_requests_policy: Option<InsecureRequestsPolicy>,
has_trustworthy_ancestor_origin: bool,
creation_sandboxing_flag_set: SandboxingFlagSet,
) -> Self
pub fn new( load_origin: LoadOrigin, url: ServoUrl, about_base_url: Option<ServoUrl>, creator_pipeline_id: Option<PipelineId>, referrer: Referrer, referrer_policy: ReferrerPolicy, inherited_secure_context: Option<bool>, inherited_insecure_requests_policy: Option<InsecureRequestsPolicy>, has_trustworthy_ancestor_origin: bool, creation_sandboxing_flag_set: SandboxingFlagSet, ) -> Self
Create a new LoadData object.
Create a new LoadData for a completely new top-level WebView that isn’t created
via APIs like window.open. This is for WebViews completely unrelated to others.