pub struct SerializableAlgorithm {
pub name: String,
}Expand description
A serializable version of the Algorithm dictionary, used by the SubtleCrypto interface.
Fields
name: StringTrait Implementations
Sourceimpl Clone for SerializableAlgorithm
impl Clone for SerializableAlgorithm
Sourcefn clone(&self) -> SerializableAlgorithm
fn clone(&self) -> SerializableAlgorithm
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SerializableAlgorithm
impl Debug for SerializableAlgorithm
Sourceimpl<'de> Deserialize<'de> for SerializableAlgorithm
impl<'de> Deserialize<'de> for SerializableAlgorithm
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MallocSizeOf for SerializableAlgorithm
impl MallocSizeOf for SerializableAlgorithm
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.