pub struct SerializableCryptoKey {
pub key_type: String,
pub extractable: bool,
pub algorithm: SerializableKeyAlgorithmAndDerivatives,
pub usages: Vec<String>,
pub handle: SerializableCryptoKeyHandle,
}Expand description
A serializable version of the CryptoKey interface.
Fields
key_type: Stringextractable: boolalgorithm: SerializableKeyAlgorithmAndDerivativesusages: Vec<String>handle: SerializableCryptoKeyHandleTrait Implementations
Sourceimpl BroadcastClone for SerializableCryptoKey
impl BroadcastClone for SerializableCryptoKey
Sourcetype Id = NamespaceIndex<CryptoKeyIndex>
type Id = NamespaceIndex<CryptoKeyIndex>
The ID type that uniquely identify each value.
Sourcefn source(data: &StructuredSerializedData) -> &Option<FxHashMap<Self::Id, Self>>
fn source(data: &StructuredSerializedData) -> &Option<FxHashMap<Self::Id, Self>>
The field from which to clone values.
Sourcefn destination(
data: &mut StructuredSerializedData,
) -> &mut Option<FxHashMap<Self::Id, Self>>
fn destination( data: &mut StructuredSerializedData, ) -> &mut Option<FxHashMap<Self::Id, Self>>
The field into which to place cloned values.
Sourcefn clone_for_broadcast(&self) -> Option<Self>
fn clone_for_broadcast(&self) -> Option<Self>
Clone this value so that it can be reused with a broadcast channel.
Only return None if cloning is impossible.
Sourceimpl Clone for SerializableCryptoKey
impl Clone for SerializableCryptoKey
Sourcefn clone(&self) -> SerializableCryptoKey
fn clone(&self) -> SerializableCryptoKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SerializableCryptoKey
impl Debug for SerializableCryptoKey
Sourceimpl<'de> Deserialize<'de> for SerializableCryptoKey
impl<'de> Deserialize<'de> for SerializableCryptoKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl MallocSizeOf for SerializableCryptoKey
impl MallocSizeOf for SerializableCryptoKey
Sourcefn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.